{%- if filetype_loop == 0 %}Project,Template Name,Template Description,Tag Name,Tag ID,Author,Product Family,Software Type,Display NameParameter ID,Data Type,Parameter Description,Instructions Text,Default Value,Required,Not Param,Param Array,Group,Order,Custom Order
{%-     if template.tags is not none %}
{%-         for tag in template.tags %}
{%-             for type in template.deviceTypes %}
{%-                 for param in template.templateParams %}
{{ project }},{{ template.name }},{{ template.description }},{{ tag.name }},{{ tag.id }},{{ template.author }},{{ type.productFamily }},{{ template.softwareType }},{{ param.displayName }},{{ param.id }},{{ param.dataType }},{{ param.description }},{{ param.instructionText }},{{ param.defaultValue }},{{ param.required }},{{ param.notParam }},{{ param.paramArray }},{{ param.group }},{{ param.order }},{{ param.customOrder }}
{%-                 endfor %}
{%-             endfor %}
{%-         endfor %}
{%-     else %}
{%-         for type in template.deviceTypes %}
{%-             for param in template.templateParams %}
{{ project }},{{ template.name }},{{ template.description }},No Tags,no Tags,{{ template.author }},{{ type.productFamily }},{{ template.softwareType }},{{ param.displayName }},{{ param.id }},{{ param.dataType }},{{ param.description }},{{ param.instructionText }},{{ param.defaultValue }},{{ param.required }},{{ param.notParam }},{{ param.paramArray }},{{ param.group }},{{ param.order }},{{ param.customOrder }}
{%-             endfor %}
{%-         endfor %}
{%-     endif %}
{%- else %}
{%-     if filetype_loop == 1 %}
# DNAC Templates
| Project | Template Name | Template Description | Tag Name | Tag ID | Author | Product Family | Software Type | Display NameParameter ID | Data Type | Parameter Description | Instructions Text | Default Value | Required | Not Param | Param Array | Group | Order | Custom Order |
| ------- | ------------- | -------------------- | -------- | ------ | ------ | -------------- | ------------- | ------------------------ | --------- | --------------------- | ----------------- | ------------- | -------- | --------- | ----------- | ----- | ----- | ------------ |
{%-     if template.tags is not none %}
{%-         for tag in template.tags %}
{%-             for type in template.deviceTypes %}
{%-                 for param in template.templateParams %}
| {{ project }} | {{ template.name }} | {{ template.description }} | {{ tag.name }} | {{ tag.id }} | {{ template.author }} | {{ type.productFamily }} | {{ template.softwareType }} | {{ param.displayName }} | {{ param.id }} | {{ param.dataType }} | {{ param.description }} | {{ param.instructionText }} | {{ param.defaultValue }} | {{ param.required }} | {{ param.notParam }} | {{ param.paramArray }} | {{ param.group }} | {{ param.order }} | {{ param.customOrder }} |
{%-                 endfor %}
{%-             endfor %}
{%-         endfor %}
{%-     else %}
{%-         for type in template.deviceTypes %}
{%-             for param in template.templateParams %}
| {{ project }} | {{ template.name }} | {{ template.description }} | No Tags | no Tags | {{ template.author }} | {{ type.productFamily }} | {{ template.softwareType }} | {{ param.displayName }} | {{ param.id }} | {{ param.dataType }} | {{ param.description }} | {{ param.instructionText }} | {{ param.defaultValue }} | {{ param.required }} | {{ param.notParam }} | {{ param.paramArray }} | {{ param.group }} | {{ param.order }} | {{ param.customOrder }} |
{%-             endfor %}
{%-         endfor %}
{%-     endif %}
{%-     else %}
{%-         if filetype_loop == 2 %}
<html><body>
<h1>DNAC Templates</h1>
<table>
  <thead>
    <tr>
      <th>Project</th>
      <th>Template Name</th>
      <th>Template Description</th>
      <th>Tag Name</th>
      <th>Tag ID</th>
      <th>Author</th>
      <th>Product Family</th>
      <th>Software Type</th>
      <th>Display NameParameter ID</th>
      <th>Data Type</th>
      <th>Parameter Description</th>
      <th>Instructions Text</th>
      <th>Default Value</th>
      <th>Required</th>
      <th>Not Param</th>
      <th>Param Array</th>
      <th>Group</th>
      <th>Order</th>
      <th>Custom Order</th>
    </tr>
  </thead>
  <tbody>
{%-     if template.tags is not none %}
{%-         for tag in template.tags %}
{%-             for type in template.deviceTypes %}
{%-                 for param in template.templateParams %}
  <tr>
    <td>{{ project }}</td>
    <td>{{ template.name }}</td>
    <td>{{ template.description }}</td>
    <td>{{ tag.name }}</td>
    <td>{{ tag.id }}</td>
    <td>{{ template.author }}</td>
    <td>{{ type.productFamily }}</td>
    <td>{{ template.softwareType }}</td>
    <td>{{ param.displayName }}</td>
    <td>{{ param.id }}</td>
    <td>{{ param.dataType }}</td>
    <td>{{ param.description }}</td>
    <td>{{ param.instructionText }}</td>
    <td>{{ param.defaultValue }}</td>
    <td>{{ param.required }}</td>
    <td>{{ param.notParam }}</td>
    <td>{{ param.paramArray }}</td>
    <td>{{ param.group }}</td>
    <td>{{ param.order }}</td>
    <td>{{ param.customOrder }}</td>
  </tr>
{%-                 endfor %}
{%-             endfor %}
{%-         endfor %}
{%-     else %}
{%-         for type in template.deviceTypes %}
{%-             for param in template.templateParams %}
  <tr>
    <td>{{ project }}</td>
    <td>{{ template.name }}</td>
    <td>{{ template.description }}</td>
    <td>No Tags</td>
    <td>No Tags</td>
    <td>{{ template.author }}</td>
    <td>{{ type.productFamily }}</td>
    <td>{{ template.softwareType }}</td>
    <td>{{ param.displayName }}</td>
    <td>{{ param.id }}</td>
    <td>{{ param.dataType }}</td>
    <td>{{ param.description }}</td>
    <td>{{ param.instructionText }}</td>
    <td>{{ param.defaultValue }}</td>
    <td>{{ param.required }}</td>
    <td>{{ param.notParam }}</td>
    <td>{{ param.paramArray }}</td>
    <td>{{ param.group }}</td>
    <td>{{ param.order }}</td>
    <td>{{ param.customOrder }}</td>
  </tr>
{%-             endfor %}
{%-         endfor %}
{%-     endif %}  
  </tbody>
</table>
</body></html>
{%-         else %}
# {{ project }}
## Template
### {{ template.name }}
#### Description: {{ template.description }}
#### Tags
{%- for tag in template.tags %}
##### Name: {{ tag.name }}
##### ID: {{ tag.id }}
{%- endfor %}
#### Author: {{ template.author }}
#### Device Types
{%- for type in template.deviceTypes %}
##### Product Family: {{ type.productFamily }}
{%- endfor %}
#### Software Type: {{ template.softwareType }}
#### Parameters
{%- for param in template.templateParams %}
##### {{ param.displayName }}
###### ID: {{ param.id }}
###### Type: {{ param.dataType }}
###### Description: {{ param.description }}
###### Instructions: {{ param.instructionText }}
###### Default Value: {{ param.defaultValue }}
###### Required: {{ param.required }}
###### Not Param: {{ param.notParam }}
###### Param Array: {{ param.paramArray }}
###### Group: {{ param.group }}
###### Order: {{ param.order }}
###### Custom Order: {{ param.customOrder }}
{%- endfor %}
{%-         endif %}
{%-     endif %}
{%- endif %}